import {Navigate, Outlet, Route, Routes as RoutesSwitch} from "react-router-dom";
import {LOGIN, MAIN, PRODUCT_ADD, PRODUCT_LIST, PRODUCT_VIEW, REGISTER} from "./constants/routes";
import AddProduct from "./containers/AddProduct/AddProduct";
import Layout from "./components/Layout/Layout";
import Products from "./containers/Products/Products";
import Register from "./containers/Auth/Register/Register";
import Login from "./containers/Auth/Login/Login";

const ProtectedRoute = ({isAllowed, redirectPath, children}) => {
    if (!isAllowed) {
        return <Navigate to={redirectPath} replace />;
    }

    return children || <Outlet/>;
};

const Routes = ({user}) => {
    const productAdd = <ProtectedRoute
        isAllowed={!!user && user.role === 'admin'}
        redirectPath={!!user ? MAIN : LOGIN}
    >
        <AddProduct />
    </ProtectedRoute>;

    return <RoutesSwitch>
        <Route element={<Layout />}>
            <Route index element={<Products />}/>
            <Route path={REGISTER} element={<Register />}/>
            <Route path={LOGIN} element={<Login />}/>
            <Route path={PRODUCT_LIST} element={<Products />}/>
            <Route path={PRODUCT_ADD} element={productAdd}/>
            <Route path={PRODUCT_VIEW} element={<h1>Show product</h1>}/>
        </Route>
    </RoutesSwitch>;
};

export default Routes;
